@@ -1,7 +1,7 @@
 """
 Calculate a motion path.
 
-COMPAS FAB v0.22.0
+COMPAS FAB v0.25.0
 """
 from ghpythonlib.componentbase import executingcomponent as component
 from scriptcontext import sticky as st
@@ -16,7 +16,7 @@ class PlanMotion(component):
 
         path_constraints = list(path_constraints) if path_constraints else None
         attached_collision_meshes = list(attached_collision_meshes) if attached_collision_meshes else None
-        planner_id = str(planner_id) if planner_id else 'RRTConnectkConfigDefault'
+        planner_id = str(planner_id) if planner_id else 'RRTConnect'
 
         if robot and robot.client and robot.client.is_connected and start_configuration and goal_constraints and compute:
             st[key] = robot.plan_motion(goal_constraints,
